@@ -1,8 +1,6 @@
 package HTML::HTML5::Parser::Charset::DecodeHandle;
 use strict;
 
-our $VERSION = '0.207_01';
-
 ## NOTE: |Message::Charset::Info| uses this module without calling
 ## the constructor.
 use HTML::HTML5::Parser::Charset::Info;
@@ -701,12 +699,10 @@ sub read ($$$;$) {
         }
         $self->{bom_checked} = 1;
       }
-      my $string = do {
-			BEGIN { $SIG{__WARN__} = sub { warn $_[0] unless $_[0] =~ /^Code point/ } }
-			Encode::decode ($self->{perl_encoding_name},
-                         $self->{byte_buffer},
-                         Encode::FB_QUIET ());
-		};
+
+      my $string = Encode::decode ($self->{perl_encoding_name},
+                                   $self->{byte_buffer},
+                                   Encode::FB_QUIET ());
       if (length $string) {
         $self->{char_buffer} = \$string;
         $self->{char_buffer_pos} = 0;
